==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/OverviewDetails.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DISPLAYONOVERVIEW" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COLOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICONPATH" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "displayonoverview",
    "color",
    "iconcode",
    "iconpath"
})
@XmlRootElement(name = "OverviewDetails")
public class OverviewDetails {

    @XmlElement(name = "DISPLAYONOVERVIEW", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String displayonoverview;
    @XmlElement(name = "COLOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected String color;
    @XmlElement(name = "ICONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iconcode;
    @XmlElement(name = "ICONPATH", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iconpath;

    /**
     * Obtient la valeur de la propriété displayonoverview.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDISPLAYONOVERVIEW() {
        return displayonoverview;
    }

    /**
     * Définit la valeur de la propriété displayonoverview.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDISPLAYONOVERVIEW(String value) {
        this.displayonoverview = value;
    }

    /**
     * Obtient la valeur de la propriété color.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLOR() {
        return color;
    }

    /**
     * Définit la valeur de la propriété color.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLOR(String value) {
        this.color = value;
    }

    /**
     * Obtient la valeur de la propriété iconcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICONCODE() {
        return iconcode;
    }

    /**
     * Définit la valeur de la propriété iconcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICONCODE(String value) {
        this.iconcode = value;
    }

    /**
     * Obtient la valeur de la propriété iconpath.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICONPATH() {
        return iconpath;
    }

    /**
     * Définit la valeur de la propriété iconpath.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICONPATH(String value) {
        this.iconpath = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/OverviewDetails.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DISPLAYONOVERVIEW" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COLOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICONPATH" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "displayonoverview",
    "color",
    "iconcode",
    "iconpath"
})
@XmlRootElement(name = "OverviewDetails")
public class OverviewDetails {

    @XmlElement(name = "DISPLAYONOVERVIEW", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String displayonoverview;
    @XmlElement(name = "COLOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected String color;
    @XmlElement(name = "ICONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iconcode;
    @XmlElement(name = "ICONPATH", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iconpath;

    /**
     * Gets the value of the displayonoverview property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDISPLAYONOVERVIEW() {
        return displayonoverview;
    }

    /**
     * Sets the value of the displayonoverview property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDISPLAYONOVERVIEW(String value) {
        this.displayonoverview = value;
    }

    /**
     * Gets the value of the color property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLOR() {
        return color;
    }

    /**
     * Sets the value of the color property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLOR(String value) {
        this.color = value;
    }

    /**
     * Gets the value of the iconcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICONCODE() {
        return iconcode;
    }

    /**
     * Sets the value of the iconcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICONCODE(String value) {
        this.iconcode = value;
    }

    /**
     * Gets the value of the iconpath property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICONPATH() {
        return iconpath;
    }

    /**
     * Sets the value of the iconpath property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICONPATH(String value) {
        this.iconpath = value;
    }

}
